Sign inSign up

brsynth/retropath2

By brsynth

•Updated over 6 years ago

Docker image containing environment to run retropath2

Image
0

718

brsynth/retropath2 repository overview

⁠Retropath2.0 docker

Perform retrosynthesis search of possible metabolic routes between a source molecule and a collection of sink molecules. Docker implementation of the KNIME retropath2.0 workflow. Takes for input the minimal (dmin) and maximal (dmax) diameter for the reaction rules and the maximal path length (maxSteps). The docker mounts a local folder and expects the following files: rules.csv, sink.csv and source.csv. We only support a single source molecule at this time.

⁠Input

Required:

  • -sinkfile: (string) Path to the sink file
  • -sourcefile: (string) Path to the source file
  • -max_steps: (integer) Maximal number of steps
  • -rulesfile: (string) Path to the rules file
  • -rulesfile_format: (string) Valid Options: tar, csv. Format of the rules file

Advanced options:

  • -topx: (integer, default: 100) For each iteration, number of rules
  • -dmin: (integer, default: 0)
  • -dmax: (integer, default: 1000)
  • -mwmax_source: (integer, default: 1000)
  • -mwmax_cof: (integer, default: 1000)
  • -timeout: (integer, default: 30) Timeout in minutes
  • -server_url: (string, default: http://0.0.0.0:8888/REST⁠) IP address of the REST service

⁠Output

  • -scope_csv: (string) Path to the output scope csv file

⁠Dependencies

⁠Building the docker

Compile the docker image if it hasen't already been done:

docker build -t brsynth/retropath2-redis .

To run the service on a localhost as the Galaxy interface, after creating the image run the REST service using the following command:

docker run -p 8888:8888 brsynth/retropath2-redis
⁠Running the test

To test the docker, untar the test.tar.xz file and run the following command:

python tool_RetroPath2.py -sinkfile test/sink.csv -sourcefile test/source.csv -rulesfile test/rules.tar -rulesfile_format tar -max_steps 3 -scope_csv test_scope.csv

⁠Contributing

Please read CONTRIBUTING.md⁠ for details on our code of conduct, and the process for submitting pull requests to us.

⁠Version

v8.0

⁠Authors

  • Melchior du Lac
  • Joan Hérisson

⁠License

This project is licensed under the MIT License - see the LICENSE.md⁠ file for details

⁠Acknowledgments

  • Thomas Duigou
⁠How to cite RetroPath2.0?

Please cite:

Delépine B, Duigou T, Carbonell P, Faulon JL. RetroPath2.0: A retrosynthesis workflow for metabolic engineers. Metabolic Engineering, 45: 158-170, 2018. DOI: https://doi.org/10.1016/j.ymben.2017.12.002⁠

Tag summary

Content type

Image

Digest

Size

1.3 GB

Last updated

over 6 years ago

docker pull brsynth/retropath2:redis